pub struct CodeTimer {
start: Instant,
min_info_time: Duration,
min_warn_time: Duration,
description: &'static str,
has_finished: bool,
}Expand description
A guard that logs code execution time when dropped.
Fields
start: InstantThe time that the code started executing.
min_info_time: DurationThe minimum duration for info-level messages.
min_warn_time: DurationThe minimum duration for warning messages.
description: &'static strThe description configured when the timer is started.
has_finished: booltrue if this timer has finished.
Implementations
Sourceimpl CodeTimer
impl CodeTimer
Sourcepub fn start() -> Self
pub fn start() -> Self
Start timing the execution of a function, method, or other code region.
See CodeTimer::start_desc for more details.
Sourcepub fn start_desc(description: &'static str) -> Self
pub fn start_desc(description: &'static str) -> Self
Start timing the execution of a function, method, or other code region.
Returns a guard that finishes timing the code when dropped,
or when CodeTimer::finish_inner() is called with an empty description.
Sourcepub fn finish_desc(self, description: &'static str)
pub fn finish_desc(self, description: &'static str)
Finish timing the execution of a function, method, or other code region.